obelisk.strategies.retry.ImmediateRetryStrategy
===============================================

.. currentmodule:: obelisk.strategies.retry

.. autoclass:: ImmediateRetryStrategy
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ImmediateRetryStrategy.__init__
      ~ImmediateRetryStrategy.make
   
   

   
   
   